@@ -1,5 +1,3 @@
-#!/usr/bin/python
-
 # FontDame-to-FontTools for OpenType Layout tables
 #
 # Source language spec is available at:
@@ -1377,7 +1375,7 @@ def main(args=None, font=None):
 
     for f in args.inputs:
         log.debug("Processing %s", f)
-        with open(f, "rt", encoding="utf-8") as f:
+        with open(f, "rt", encoding="utf-8-sig") as f:
             table = build(f, font, tableTag=args.tableTag)
         blob = table.compile(font)  # Make sure it compiles
         decompiled = table.__class__()
